{% extends "admin/base.html" %}
{% load i18n %}

{% block title %}Rosetta{% endblock %}

{% block extrastyle %}
<style type="text/css" media="screen">
{% include 'rosetta/css/rosetta.css' %}
#rosetta-version {
    margin: 20px 0;
    font-size: 0.8em;
    color: #777;
}
</style>
{% endblock %}

{% block extrahead %}
<script src="http://www.google.com/jsapi" type="text/javascript"></script>
<script type="text/javascript">
//<!--
    google.load("jquery", "1.3");
    {% if ENABLE_TRANSLATION_SUGGESTIONS %}google.load("language", "1");{% endif %}
    {% include 'rosetta/js/rosetta.js' %}
//-->
</script>
{% endblock %}

{% block breadcrumbs %}
<nav class="" id="grp-breadcrumbs">
	<header style="display:none"><h1>Breadcrumbs</h1></header>
	<ul class="grp-horizontal-list">
		<li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></li>
		<li>Rosetta</li>
	</ul>
</nav>

{% endblock %}

{% block content_title %}
<h1 id="site-name"><a href="{% url 'rosetta-pick-file' %}">Rosetta</a> {% block content_subtitle %}{% endblock %}</h1>
{% endblock %}


{% block content %}
{% block main %}{% endblock %}
<div id="rosetta-version">
    <a href="http://code.google.com/p/django-rosetta">Rosetta</a> <span class="version">{{version}}</span>
</div>
{% endblock %}
